*----------------------------------------------------------------------------*
* Code to generate percentiles in the income distribuion of private sector earnings                                     
* Brazil 2001 and 2004 (excluding rural north)
* PNAD individual microdata (from IBGE https://www.ibge.gov.br/)
* Author: Marc Morgan
*----------------------------------------------------------------------------*

clear
use "/Users/marcmorgan/Google Drive/PhD/Brazil/Income distribution/WID/Data/Mircodata_surveys/PNAD/2001/Dados/pes2001.dta" // repeat for each year
set more off

*----------------------------------------------------------------------------*
* Variable definitions
*----------------------------------------------------------------------------*
rename v0101 year
rename v0102 control
rename v0103 series
rename v0302 sex
rename v8005 age
rename v0402 famstatus
rename v9001 working // yes==1
rename v9042 formal //formal labour contract==2
rename v9906 occuptype
rename v9073 rural
rename v9059 contrib1 // social contributions paid from primary employment==1
rename v9085 contribprev // social contributions paid in previous employment==1
rename v9099 contrib2 // social contributions paid from secondary employment==1
rename v9088 union // rural workers==2
rename v9531 ymonet
rename v9532 yjob1
rename v9982 yjob2
rename v1022 yjob3
rename v1251 pens1 // pensioner receiving pension from own contributions
rename v1252 ypens1
rename v1254 pens2 // pensioner receiving a pension from a deceased relative
rename v1255 ypens2
rename v1258 ypens3
rename v1261 ypens4
rename v1264 yallow
rename v1267 yrent
rename v1270 ygift
rename v1273 yfinancial
rename v9092 employ2 // self-employed==3, employer==4
rename v9096 servant // civil servant in secondary job, yes==2, no==4
rename v9097 formal2 // formal contract in secondary job, yes==1
rename v4756 employ1  //v4756 in 2001 survey, v4706 in rest // self-employed==9, employer==10
rename v4754 active //v4754 in 2001 survey, v4713 in rest
//rename v4714 employed // yes==1
//rename v4805 employedweek // yes==1
//rename v90531 CNPJ // Is employment registered in the CNPJ? yes==1 - not asked before 2009
//rename v4719 ywork //
//rename v4720 yall1 //
//rename v4721 yhh1 //
//rename v4722 yfam1 //
//rename v4723 famtype //
rename v4724 famsize
rename v4728 location
rename v4729 weight 

* Unique id for observations
gen id=_n

tostring control series, replace
gen famid=control+series

*----------------------------------------------------------------------------*
* Define minimum wage levels
*----------------------------------------------------------------------------*

gen minwage=.
replace minwage=180 if year==2001
replace minwage=200 if year==2002
replace minwage=240 if year==2003
replace minwage=260 if year==2004
replace minwage=300 if year==2005
replace minwage=350 if year==2006
replace minwage=380 if year==2007
replace minwage=415 if year==2008
replace minwage=465 if year==2009
replace minwage=510 if year==2010
replace minwage=545 if year==2011
replace minwage=622 if year==2012
replace minwage=678 if year==2013
replace minwage=724 if year==2014
replace minwage=788 if year==2015

gen yassist=yfinancial
gen yunempl=yfinancial
replace yfinancial=. if yfinancial<=(minwage*2)
replace yunempl=. if (yunempl<=minwage | yunempl>(minwage*2))
replace yassist=. if yassist>minwage

*----------------------------------------------------------------------------*
* Define monthly exemption limit on DIRPF
*----------------------------------------------------------------------------*

gen exemptIRPF=.
replace exemptIRPF=900 if year==2001
replace exemptIRPF=1058 if year==2002 
replace exemptIRPF=1058 if year==2003
replace exemptIRPF=1058 if year==2004
replace exemptIRPF=1164 if year==2005
replace exemptIRPF=1258 if year==2006
replace exemptIRPF=1314 if year==2007
replace exemptIRPF=1373 if year==2008 
replace exemptIRPF=1435 if year==2009
replace exemptIRPF=1450 if year==2010
replace exemptIRPF=1567 if year==2011
replace exemptIRPF=1638 if year==2012
replace exemptIRPF=1711 if year==2013
replace exemptIRPF=1788 if year==2014
replace exemptIRPF=1904 if year==2015

*----------------------------------------------------------------------------*
* Define monthly maximum limit on contributing salary for INSS
*----------------------------------------------------------------------------*

gen maxlimitINSS=.
replace maxlimitINSS=1430 if year==2001
replace maxlimitINSS=1562 if year==2002 
replace maxlimitINSS=1870 if year==2003
replace maxlimitINSS=2509 if year==2004
replace maxlimitINSS=2669 if year==2005
replace maxlimitINSS=2802 if year==2006
replace maxlimitINSS=2895 if year==2007
replace maxlimitINSS=3039 if year==2008 
replace maxlimitINSS=3219 if year==2009
replace maxlimitINSS=3468 if year==2010
replace maxlimitINSS=3692 if year==2011
replace maxlimitINSS=3917 if year==2012
replace maxlimitINSS=4159 if year==2013
replace maxlimitINSS=4391 if year==2014
replace maxlimitINSS=4664 if year==2015

*----------------------------------------------------------------------------*
* Filters (benchmark: narrow equal-split)
*----------------------------------------------------------------------------*


// drop if (uf==11 | uf==12 | uf==13 | uf==14 | uf==15 | uf==16) & (location==4 | location==5 | location==6 | location==7 | location==8) // drops rural areas of north for 2004 survey

* Drop misreported/nondeclared income
replace yjob1=. if (yjob1==999999999999 | yjob1==999999995904)
replace yjob2=. if (yjob2==999999999999 | yjob2==999999995904)
replace yjob3=. if (yjob3==999999999999 | yjob3==999999995904)
replace ypens1=. if (ypens1==999999999999 | ypens1==999999995904)
replace ypens2=. if (ypens2==999999999999 | ypens2==999999995904) 
replace ypens3=. if (ypens3==999999999999 | ypens3==999999995904) 
replace ypens4=. if (ypens4==999999999999 | ypens4==999999995904)
replace yallow=. if (yallow==999999999999  | yallow==999999995904)
replace yunempl=. if (yunempl==999999999999 | yunempl==999999995904)
replace yrent=. if (yrent==999999999999 | yrent==999999995904)
replace yfinancial=. if (yfinancial==999999999999 | yfinancial==999999995904)
replace ygift=. if (ygift==999999999999 | ygift==999999995904)
replace yassist=. if (yassist==999999999999 | yassist==999999995904)


* Missing values & zeros

replace yjob1=0 if (yjob1==. & employ1==13) // workers whose principal job is non remunerated
drop if (yjob1==. | yjob1==0) & (ymonet==1 | employ1==1 | employ1==2 | employ1==3 | employ1==4 | employ1==6 | employ1==7 | employ1==9 | employ1==10) // drop workers whose principal job is remunerated in cash but declare zero income or n.a

*----------------------------------------------------------------------------*
* Individual adult income
*----------------------------------------------------------------------------*

keep if age>=20 // | (age<20 & yind!=. & yind!=0)  /* Only keeps people above 20 years | (age<20 & yind!=. & yind!=0 & ygift!=. & ygift!=0) */
drop if weight==0   /* drops null weights */

* Employee work income (formal & informal)
gen ywork1=.
replace ywork1=yjob1 if (employ1!=9 & employ1!=10)
gen ywork2=.
replace ywork2=yjob2 if (employ2!=3 & employ2!=4)
egen ywork=rowtotal(ywork1 ywork2 yjob3)

** Employer income **
// Scenario A: Capital withdrawals are assumed to be the excess payments over the minimum wage. Pro-labore payments are = minimum wage
gen ycapemployer1A=.
replace ycapemployer1A=yjob1-minwage if (employ1==10 & yjob1>=minwage)

gen ylabemployer1A=yjob1-ycapemployer1A if (employ1==10 & yjob1>=minwage)
replace ylabemployer1A=yjob1 if (employ1==10 & yjob1<minwage)

gen ycapemployer2A=.
replace ycapemployer2A=yjob2-minwage if (employ2==4 & yjob2>=minwage)

gen ylabemployer2A=yjob2-ycapemployer2A if (employ2==4 & yjob2>=minwage)
replace ylabemployer2A=yjob2 if (employ2==4 & yjob2<minwage)

egen ycapemployerA=rowtotal(ycapemployer1A ycapemployer2A)
egen ylabemployerA=rowtotal(ylabemployer1A ylabemployer2A)
egen yemployerA=rowtotal(ylabemployerA ycapemployerA)

// Scenario B (benchmark case): Capital withdrawals are assumed to be the excess payments over the exemption limit on DIRPF. Pro-labore payments are <= exemption limit on DIRPF
gen ycapemployer1B=.
replace ycapemployer1B=yjob1-exemptIRPF if (employ1==10 & yjob1>=exemptIRPF)

gen ylabemployer1B=yjob1-ycapemployer1B if (employ1==10 & yjob1>=exemptIRPF)
replace ylabemployer1B=yjob1 if (employ1==10 & yjob1<exemptIRPF)

gen ycapemployer2B=.
replace ycapemployer2B=yjob2-exemptIRPF if (employ2==4 & yjob2>=exemptIRPF)

gen ylabemployer2B=yjob2-ycapemployer2B if (employ2==4 & yjob2>=exemptIRPF)
replace ylabemployer2B=yjob2 if (employ2==4 & yjob2<exemptIRPF)

egen ycapemployerB=rowtotal(ycapemployer1B ycapemployer2B)
egen ylabemployerB=rowtotal(ylabemployer1B ylabemployer2B)
egen yemployerB=rowtotal(ylabemployerB ycapemployerB)

// Scenario C: Capital withdrawals are assumed to be the excess payments over the maximum limit on contributing salary for INSS. Pro-labore payments are <= max limit on INSS contributing salary
gen ycapemployer1C=.
replace ycapemployer1C=yjob1-maxlimitINSS if (employ1==10 & yjob1>=maxlimitINSS)

gen ylabemployer1C=yjob1-ycapemployer1C if (employ1==10 & yjob1>=maxlimitINSS)
replace ylabemployer1C=yjob1 if (employ1==10 & yjob1<maxlimitINSS)

gen ycapemployer2C=.
replace ycapemployer2C=yjob2-maxlimitINSS if (employ2==4 & yjob2>=maxlimitINSS)

gen ylabemployer2C=yjob2-ycapemployer2C if (employ2==4 & yjob2>=maxlimitINSS)
replace ylabemployer2C=yjob2 if (employ2==4 & yjob2<maxlimitINSS)

egen ycapemployerC=rowtotal(ycapemployer1C ycapemployer2C)
egen ylabemployerC=rowtotal(ylabemployer1C ylabemployer2C)
egen yemployerC=rowtotal(ylabemployerC ycapemployerC)


* Self employed income (mixed income)
gen ymixed1=.
replace ymixed1=yjob1 if employ1==9
gen ymixed2=.
replace ymixed2=yjob2 if employ2==3
egen ymixed=rowtotal(ymixed1 ymixed2)
gen ymixedcap=ymixed-exemptIRPF if ymixed>=exemptIRPF
gen ymixedlab=ymixed-ymixedcap if ymixed>=exemptIRPF
replace ymixedlab=ymixed if ymixed<exemptIRPF

* Pension income
egen ypens=rowtotal(ypens1 ypens2 ypens3 ypens4)

* Labour, capital and total individual income, Labour income of employees, employers and other contributors to social security
egen ylabour=rowtotal(ywork ypens yallow yunempl ylabemployerB)
egen ycapital=rowtotal(yrent yfinancial ycapemployerB)
egen yindm=rowtotal(ylabour ycapital ymixed) // total monetary income before taxes on labour income and before social transfers for individuals 20+

gen yemployee1m=yjob1 if (employ1==1 & contrib1==1)  
gen yemployee2m=yjob2 if (employ2==1 & servant!=2 & formal2==1 & contrib2==1)
egen yemployeem=rowtotal(yemployee1m yemployee2m) // Earnings of private formal employees contributing to social security

gen yemployerscm1=ylabemployer1B if contrib1==1  
gen yemployerscm2=ylabemployer2B if contrib2==1 
egen yemployerscm=rowtotal(yemployerscm1 yemployerscm2) // employer contributing salaries
egen yotherscm=rowtotal(ywork ymixed) if ((employ1==4 | employ1==6 | employ1==7 | employ1==9 | employ1==11 | employ1==12 | employ1==13) & contrib1==1)  | ((employ2==2 | employ2==3 | employ2==5 | employ2==6) & contrib1==1) //other workers
egen yindscm=rowtotal(yemployerscm yotherscm)

gen yemployeencm=ywork if (employ1==1 & contrib1!=1) | (employ2==1 & servant!=2 & contrib2!=1) // non-contributing employees

*----------------------------------------------------------------------------*
* Annual income series
*----------------------------------------------------------------------------*

gen yemployeea=yemployeem*12
gen yindsca=yindscm*12

* Adding 13th salary (bonus defined by law for all formal employees)
gen y13a=yjob1 if employ1==1 
gen y13b=yjob2 if (employ2==1 & formal2==1)
egen yemployee=rowtotal(yemployeea y13a y13b)
gen y13ind=yjob1 if (employ1==6)
egen yindsc=rowtotal(yindsca y13ind)

*----------------------------------------------------------------------------*
* Totals & averages
*----------------------------------------------------------------------------*

quietly sum yemployee [fw=weight] if (employ1==1 & contrib1==1) | (employ2==1 & servant!=2 & formal2==1 & contrib2==1)
gen tot = r(sum)
gen meant = r(mean)
gen poptot = r(sum_w) 

*----------------------------------------------------------------------------*
* Generate fractiles
*----------------------------------------------------------------------------*

sort yemployee , stable
gen cumweight=sum(weight) if (employ1==1 & contrib1==1) | (employ2==1 & servant!=2 & formal2==1 & contrib2==1)
format %20.0g cumweight
gen cumfrq=cumweight/poptot
format %40.0g cumfrq

*----------------------------------------------------------------------------* 
* Generate percentiles & summary stats (Mean, thresholds, shares, etc...)
*----------------------------------------------------------------------------*

* Percentiles P0-P99

gen percentile=.
forvalues i = 0(1)99 {
replace percentile=`i' if (cumfrq>=(`i')/100 & cumfrq<=(`i'+1)/100) /*    gives percentile=i if i-1<cumfreq<=i   */
} 

forvalues i = 0(1)99 {
quietly sum yemployee [fw=weight] if per==`i' 
gen mean`i' = r(mean)
gen tot`i' = r(sum)
gen fractile`i' = r(min) 
//gen share`i' = tot`i'/tot 
//gen pop`i' = r(sum_w)/poptot 
}

*----------------------------------------------------------------------------* 
* Output results
*----------------------------------------------------------------------------*

keep year tot poptot mean*
//keep year poptot fractile*
keep if _n==1

export excel using "/Users/marcmorgan/Desktop/survey mean incomes_contributors2001exclrural.xlsx", firstrow(variables) 
//export excel using "/Users/marcmorgan/Desktop/Survey fractile incomes.xlsx", sheet("`year'") sheetreplace firstrow(variables) 

exit






