*----------------------------------------------------------------------------*
* Code to generate percentiles in the income distribuion                                      
* Brazil 2001 and 2004 (excluding rural north)
* PNAD individual microdata (from IBGE https://www.ibge.gov.br/)
* Author: Marc Morgan
*----------------------------------------------------------------------------*

clear
use "/Users/marcmorgan/Google Drive/PhD/Brazil/Income distribution/WID/Data/Mircodata_surveys/PNAD/2015/Dados/pes2015.dta" // repeat for each year
set more off

*----------------------------------------------------------------------------*
* Variable definitions
*----------------------------------------------------------------------------*
rename v0101 year
rename v0102 control
rename v0103 series
rename v0302 sex
rename v8005 age
rename v0402 famstatus
rename v9001 working // yes==1
rename v9042 formal //formal labour contract==2
rename v9906 occuptype
rename v9073 rural
rename v9085 contrib // social contributions paid in previous employment==1
rename v9088 union // rural workers==2
rename v9531 ymonet
rename v9532 yjob1
rename v9982 yjob2
rename v1022 yjob3
rename v1251 pens1 // pensioner receiving pension from own contributions
rename v1252 ypens1
rename v1254 pens2 // pensioner receiving a pension from a deceased relative
rename v1255 ypens2
rename v1258 ypens3
rename v1261 ypens4
rename v1264 yallow
rename v1267 yrent
rename v1270 ygift
rename v1273 yfinancial
rename v9092 employ2 // self-employed==3, employer==4
rename v4706 employ1 //v4756 in 2001 survey, v4706 in rest // self-employed==9, employer==10
rename v4713 active //v4754 in 2001 survey, v4713 in rest
//rename v4714 employed // yes==1
//rename v4805 employedweek // yes==1
//rename v90531 CNPJ // Is employment registered in the CNPJ? yes==1 - not asked before 2009
//rename v4711 SSC //
//rename v4719 ywork //
//rename v4720 yall1 //
//rename v4721 yhh1 //
//rename v4722 yfam1 //
//rename v4723 famtype //
rename v4724 famsize
rename v4728 location
rename v4729 weight 

* Unique id for observations
gen id=_n

tostring control series, replace
gen famid=control+series

*----------------------------------------------------------------------------*
* Define minimum wage levels
*----------------------------------------------------------------------------*

gen minwage=.
replace minwage=180 if year==2001
replace minwage=200 if year==2002
replace minwage=240 if year==2003
replace minwage=260 if year==2004
replace minwage=300 if year==2005
replace minwage=350 if year==2006
replace minwage=380 if year==2007
replace minwage=415 if year==2008
replace minwage=465 if year==2009
replace minwage=510 if year==2010
replace minwage=545 if year==2011
replace minwage=622 if year==2012
replace minwage=678 if year==2013
replace minwage=724 if year==2014
replace minwage=788 if year==2015

gen yassist=yfinancial
gen yunempl=yfinancial
replace yfinancial=. if yfinancial<=(minwage*2)
replace yunempl=. if (yunempl<=minwage | yunempl>(minwage*2))
replace yassist=. if yassist>minwage
*----------------------------------------------------------------------------*
* Define monthly exemption limit on DIRPF
*----------------------------------------------------------------------------*

gen exemptIRPF=.
replace exemptIRPF=900 if year==2001
replace exemptIRPF=1058 if year==2002 
replace exemptIRPF=1058 if year==2003
replace exemptIRPF=1058 if year==2004
replace exemptIRPF=1164 if year==2005
replace exemptIRPF=1258 if year==2006
replace exemptIRPF=1314 if year==2007
replace exemptIRPF=1373 if year==2008 
replace exemptIRPF=1435 if year==2009
replace exemptIRPF=1450 if year==2010
replace exemptIRPF=1567 if year==2011
replace exemptIRPF=1638 if year==2012
replace exemptIRPF=1711 if year==2013
replace exemptIRPF=1788 if year==2014
replace exemptIRPF=1904 if year==2015

*----------------------------------------------------------------------------*
* Define monthly maximum limit on contributing salary for INSS
*----------------------------------------------------------------------------*

gen maxlimitINSS=.
replace maxlimitINSS=1430 if year==2001
replace maxlimitINSS=1562 if year==2002 
replace maxlimitINSS=1870 if year==2003
replace maxlimitINSS=2509 if year==2004
replace maxlimitINSS=2669 if year==2005
replace maxlimitINSS=2802 if year==2006
replace maxlimitINSS=2895 if year==2007
replace maxlimitINSS=3039 if year==2008 
replace maxlimitINSS=3219 if year==2009
replace maxlimitINSS=3468 if year==2010
replace maxlimitINSS=3692 if year==2011
replace maxlimitINSS=3917 if year==2012
replace maxlimitINSS=4159 if year==2013
replace maxlimitINSS=4391 if year==2014
replace maxlimitINSS=4664 if year==2015

*----------------------------------------------------------------------------*
* Filters (benchmark: narrow equal-split)
*----------------------------------------------------------------------------*

// drop if (SSC==2 | SSC==.) // only keeps contributors to social security (to compare with tax data).

//drop if (uf==11 | uf==12 | uf==13 | uf==14 | uf==15 | uf==16) & (location==4 | location==5 | location==6 | location==7 | location==8) // drops rural areas of north for 2004 survey

// drop misreported/nondeclared income
replace yjob1=. if (yjob1==999999999999 | yjob1==999999995904)
replace yjob2=. if (yjob2==999999999999 | yjob2==999999995904)
replace yjob3=. if (yjob3==999999999999 | yjob3==999999995904)
replace ypens1=. if (ypens1==999999999999 | ypens1==999999995904)
replace ypens2=. if (ypens2==999999999999 | ypens2==999999995904) 
replace ypens3=. if (ypens3==999999999999 | ypens3==999999995904) 
replace ypens4=. if (ypens4==999999999999 | ypens4==999999995904)
replace yallow=. if (yallow==999999999999  | yallow==999999995904)
replace yunempl=. if (yunempl==999999999999 | yunempl==999999995904)
replace yrent=. if (yrent==999999999999 | yrent==999999995904)
replace yfinancial=. if (yfinancial==999999999999 | yfinancial==999999995904)
replace ygift=. if (ygift==999999999999 | ygift==999999995904)
replace yassist=. if (yassist==999999999999 | yassist==999999995904)


* Missing values & zeros

replace yjob1=0 if (yjob1==. & employ1==13) // workers whose principal job is non remunerated
drop if (yjob1==. | yjob1==0) & (ymonet==1 | employ1==1 | employ1==2 | employ1==3 | employ1==4 | employ1==6 | employ1==7 | employ1==9 | employ1==10) // drop workers whose principal job is remunerated in cash but declare zero income or n.a

*----------------------------------------------------------------------------*
* Individual adult income
*----------------------------------------------------------------------------*

keep if age>=20 // | (age<20 & yind!=. & yind!=0)  /* Only keeps people above 20 years | (age<20 & yind!=. & yind!=0 & ygift!=. & ygift!=0) */
drop if weight==0   /* drops null weights */

* Employee work income (formal & informal)
gen ywork1=.
replace ywork1=yjob1 if (employ1!=9 & employ1!=10)
gen ywork2=.
replace ywork2=yjob2 if (employ2!=3 & employ2!=4)
egen ywork=rowtotal(ywork1 ywork2 yjob3)

** Employer income **
// Scenario A: Capital withdrawals are assumed to be the excess payments over the minimum wage. Pro-labore payments are = minimum wage
gen ycapemployer1A=.
replace ycapemployer1A=yjob1-minwage if (employ1==10 & yjob1>=minwage)

gen ylabemployer1A=yjob1-ycapemployer1A if (employ1==10 & yjob1>=minwage)
replace ylabemployer1A=yjob1 if (employ1==10 & yjob1<minwage)

gen ycapemployer2A=.
replace ycapemployer2A=yjob2-minwage if (employ2==4 & yjob2>=minwage)

gen ylabemployer2A=yjob2-ycapemployer2A if (employ2==4 & yjob2>=minwage)
replace ylabemployer2A=yjob2 if (employ2==4 & yjob2<minwage)

egen ycapemployerA=rowtotal(ycapemployer1A ycapemployer2A)
egen ylabemployerA=rowtotal(ylabemployer1A ylabemployer2A)
egen yemployerA=rowtotal(ylabemployerA ycapemployerA)

// Scenario B (benchmark case): Capital withdrawals are assumed to be the excess payments over the exemption limit on DIRPF. Pro-labore payments are <= exemption limit on DIRPF
gen ycapemployer1B=.
replace ycapemployer1B=yjob1-exemptIRPF if (employ1==10 & yjob1>=exemptIRPF)

gen ylabemployer1B=yjob1-ycapemployer1B if (employ1==10 & yjob1>=exemptIRPF)
replace ylabemployer1B=yjob1 if (employ1==10 & yjob1<exemptIRPF)

gen ycapemployer2B=.
replace ycapemployer2B=yjob2-exemptIRPF if (employ2==4 & yjob2>=exemptIRPF)

gen ylabemployer2B=yjob2-ycapemployer2B if (employ2==4 & yjob2>=exemptIRPF)
replace ylabemployer2B=yjob2 if (employ2==4 & yjob2<exemptIRPF)

egen ycapemployerB=rowtotal(ycapemployer1B ycapemployer2B)
egen ylabemployerB=rowtotal(ylabemployer1B ylabemployer2B)
egen yemployerB=rowtotal(ylabemployerB ycapemployerB)

// Scenario C: Capital withdrawals are assumed to be the excess payments over the maximum limit on contributing salary for INSS. Pro-labore payments are <= max limit on INSS contributing salary
gen ycapemployer1C=.
replace ycapemployer1C=yjob1-maxlimitINSS if (employ1==10 & yjob1>=maxlimitINSS)

gen ylabemployer1C=yjob1-ycapemployer1C if (employ1==10 & yjob1>=maxlimitINSS)
replace ylabemployer1C=yjob1 if (employ1==10 & yjob1<maxlimitINSS)

gen ycapemployer2C=.
replace ycapemployer2C=yjob2-maxlimitINSS if (employ2==4 & yjob2>=maxlimitINSS)

gen ylabemployer2C=yjob2-ycapemployer2C if (employ2==4 & yjob2>=maxlimitINSS)
replace ylabemployer2C=yjob2 if (employ2==4 & yjob2<maxlimitINSS)

egen ycapemployerC=rowtotal(ycapemployer1C ycapemployer2C)
egen ylabemployerC=rowtotal(ylabemployer1C ylabemployer2C)
egen yemployerC=rowtotal(ylabemployerC ycapemployerC)


* Self employed income (mixed income)
gen ymixed1=.
replace ymixed1=yjob1 if employ1==9
gen ymixed2=.
replace ymixed2=yjob2 if employ2==3
egen ymixed=rowtotal(ymixed1 ymixed2)

* Pension income
egen ypens=rowtotal(ypens1 ypens2 ypens3 ypens4)


/* Excluding non-contributory pensions for rural workers
gen ypensrural=.
replace ypensrural=minwage if (rural!=. | union==2) & age>=60 & sex==2 & (ypens>=minwage) // male agricultural workers
replace ypensrural=minwage if (rural!=. | union==2) & age>=55 & sex==4 & (ypens>=minwage) // female agricultural workers
gen ypensc1=ypens-ypensrural */

* Excluding non-contributory pensions
/* gen ypensnc=.
replace ypensnc=minwage if contrib!=1 & (rural==. | union!=2) & (ypens>=minwage) // noncontributors in previous nonagricultural employment whose pension income is at least as much as minwage
gen ypensc2=ypens-ypensnc */

* Labour, capital and total individual income
egen ylabour=rowtotal(ywork ypens yallow yunempl ylabemployerB)
egen ycapital=rowtotal(yrent yfinancial ycapemployerB)
egen yindm=rowtotal(ylabour ycapital ymixed) // total monetary income before taxes on labour income and before social transfers for individuals 20+
egen yindm1=rowtotal(ypens yunempl ycapital)

* Labour, capital & mixed income shares
gen ylab=ylabour*weight
gen ycap=ycapital*weight
gen ymix=ymixed*weight

egen ylabtot=sum(ylab)
egen ycaptot=sum(ycap)
egen ymixtot=sum(ymix)
format %40.0g ylabtot ycaptot ymixtot
gen labshare=ylabtot/(ylabtot+ycaptot+ymixtot)
gen capshare=ycaptot/(ylabtot+ycaptot+ymixtot)

* Population earning less than min wage from principal job/earnings
//Employees 
quietly sum ywork1 [fw=weight] if formal==2 & ywork1>0
gen popwork = r(sum_w)
quietly sum ywork1 [fw=weight] if formal==2 & ywork1>0 & ywork1<minwage
gen popworkmin = r(sum_w)
//Informal workers
quietly sum ywork1 [fw=weight] if formal!=2 & ywork1>0
gen popworkinf = r(sum_w)
quietly sum ywork1 [fw=weight] if formal!=2 & ywork1>0 & ywork1<minwage
gen popworkinfmin = r(sum_w)
//Self-employed 
quietly sum ymixed1 [fw=weight] if ymixed1>0
gen popmixed = r(sum_w)
quietly sum ymixed1 [fw=weight] if ymixed1>=0 & ymixed1<minwage
gen popmixmin = r(sum_w)
//Employers
quietly sum yemployer1 [fw=weight] if yemployer1>0
gen popemployer = r(sum_w)
quietly sum yemployer1 [fw=weight] if yemployer1>0 & yemployer1<minwage
gen popemplmin = r(sum_w)

egen yoccup=rowtotal(ywork ymixed yemployer)

//Pensioners1
quietly sum ypens1 [fw=weight] if ypens1>0 & (yoccup==. | yoccup==0)
gen poppens1 = r(sum_w) 
quietly sum ypens1 [fw=weight] if ypens1>0 & ypens1<minwage
gen poppens1min = r(sum_w)
//Pensioners2
quietly sum ypens2 [fw=weight] if ypens2>0 & (ypens1==0 | ypens1==.) & (yoccup==. | yoccup==0)
gen poppens2 = r(sum_w) 
quietly sum ypens2 [fw=weight] if ypens2>0 & ypens2<minwage
gen poppens2min = r(sum_w)

*----------------------------------------------------------------------------*
* Annual income series
*----------------------------------------------------------------------------*

gen yinda=yindm*12 // annual adult income monthly values x 12 

* Adding 13th salary (bonus defined by law for all formal employees and retired workers) - benchmark defintion
egen y13a=rowtotal(yjob1) if (employ1==1 | employ1==6)
egen y13b=rowtotal(ypens1) if (active==2 & pens1==1)
egen y13c=rowtotal(ypens2) if (active==2 & pens2==2 & pens1!=1)
egen yind=rowtotal(yinda y13a y13b y13c)

/* gen yadult1=yadultm1*12 // monthly values x 12 - alternative definition */
format %40.0g yind

*----------------------------------------------------------------------------*
* Equal split adult monthly income (Benchmark definition) 
*----------------------------------------------------------------------------*

gen adult=0
replace adult=1 if (famstatus==1 | famstatus==2)

bysort famid (adult): egen yindadult=sum(yind) 
bysort famid (adult): egen adultstot=sum(adult)
gen yadult=yindadult/adultstot if adult==1
replace yadult=yind if adult==0 

** Individual adult montly work income (Alternative definition 2) ** Alternative definition 1 is individual adult income yind

/* bysort famid adult: egen yindadultm1=sum(yind1)
gen yequalsp=yindadultm1/adultstot
gen yadultm1=yequalsp+yjob if adult==1 // Only capital income, pensions and unemployment benefits are equally split within couples.
replace yadultm1=yind if adult==0 */

* # household heads and # dependents of each household head

gen hh=1 if (famstatus==1 & yadult!=.)
gen pophh=hh*weight
egen pophhtot=sum(pophh)

gen dep=(famsize-1) if (famstatus==1 & yadult!=.)
gen popdep=dep*weight
egen popdeptot=sum(popdep)
format %20.0g pophhtot popdeptot

*----------------------------------------------------------------------------*
* Totals & averages
*----------------------------------------------------------------------------*

quietly sum yadult [fw=weight]
gen tot = r(sum)
gen meant = r(mean)
gen poptot = r(sum_w)
quietly sum age [fw=weight]
gen agem = r(mean)

replace sex=0 if sex==4
quietly sum sex [fw=weight]
gen sexm=r(mean)

*----------------------------------------------------------------------------*
* Generate fractiles
*----------------------------------------------------------------------------*

sort yadult , stable
gen cumweight=sum(weight)
format %20.0g cumweight
gen cumfrq=cumweight/poptot
format %40.0g cumfrq

*----------------------------------------------------------------------------*
* Lorenz curve and GINI
*----------------------------------------------------------------------------*

* Estimate Lorenz curve

egen double totfreq=total(weight)
gen double freq=weight/totfreq
recast double freq
format %20.0g freq

gen double X=cumfrq /* X is the cumulative frequency variable (x-axis on Lorenz graph)*/

gen double y=freq*yadult
gen double cumy=freq[1]*yadult[1]
replace cumy=y+cumy[_n-1] if [_n>1]

quietly sum cumy 
gen double Y=cumy/r(max)  /* Y is the cumulative share of income (y-axis on Lorenz graph)*/

* Estimate decile shares and Gini (check)

pshare yadult [fw=weight] , nquantiles(10) gini 

*----------------------------------------------------------------------------* 
* Generate percentiles & summary stats (Mean, thresholds, shares, etc...)
*----------------------------------------------------------------------------*

* Percentiles P0-P99

gen percentile=.
forvalues i = 0(1)99 {
replace percentile=`i' if (cumfrq>=(`i')/100 & cumfrq<=(`i'+1)/100) /*    gives percentile=i if i-1<cumfreq<=i   */
} 

forvalues i = 0(1)99 {
quietly sum yadult [fw=weight] if per==`i'
gen mean`i' = r(mean)
gen tot`i' = r(sum)
gen fractile`i' = r(min) 
//gen share`i' = tot`i'/tot 
//gen pop`i' = r(sum_w)/poptot 
}

/* quietly sum cumfrq if per==`i'
gen minfrq`i'=r(min)  
gen maxfrq`i'=r(max)
gen errortop`i'=(`i'/100)-maxfrq`i'
gen errobottom`i'= (`i'-1)/100-minfrq`i' */

* Percentiles P99-P99.9

gen percentileP99_i=.
forvalues i = 0(1)9 {
replace percentileP99_i=`i' if (cumfrq>=0.99+(`i')/1000 & cumfrq<=0.99+(`i'+1)/1000) /*    gives percentileP99=i if i<=cumfreq<i+1   */
}

forvalues i = 0(1)9 {
quietly sum yadult [fw=weight] if percentileP99_i==`i'
gen meanP99_`i' = r(mean)
gen totP99_`i' = r(sum)
gen fractileP99_`i' = r(min) 
// gen share99_`i' = tot`i'/tot 
// gen pop99_`i' = r(sum_w)/poptot  
}

* Percentiles P99.9-P99.99

gen percentileP99_9i=.
forvalues i = 0(1)9 {
replace percentileP99_9i=`i' if (cumfrq>=0.999+(`i')/10000 & cumfrq<=0.999+(`i'+1)/10000) /*    gives percentileP99_9i=i if i-1<cumfreq<=i   */
}

forvalues i = 0(1)9 {
quietly sum yadult [fw=weight] if percentileP99_9i==`i'
gen meanP99_9`i' = r(mean)
gen totP99_9`i' = r(sum)
gen fractileP99_9`i' = r(min) 
// gen share99_9`i' = tot`i'/tot 
// gen pop99_9`i' = r(sum_w)/poptot  
}

* Percentiles P99.99-P99.999

gen percentileP99_99i=.
forvalues i = 0(1)9 {
replace percentileP99_99i=`i' if (cumfrq>=0.9999+(`i')/100000 & cumfrq<=0.9999+(`i'+1)/100000) //    gives percentileP99_99i=i if i-1<cumfreq<=i  
} 
 
forvalues i = 0(1)9 {
quietly sum yadult [fw=weight] if percentileP99_99i==`i'
gen meanP99_99`i' = r(mean)
gen totP99_99`i' = r(sum)
gen fractileP99_99`i' = r(min) 
// gen share99_99`i' = tot`i'/tot 
// gen pop99_99`i' = r(sum_w)/poptot  
} 

*----------------------------------------------------------------------------* 
* Output results
*----------------------------------------------------------------------------*

keep year tot poptot mean*
//keep year poptot fractile*
keep if _n==1

export excel using "/Users/marcmorgan/Desktop/Survey mean incomes.xlsx", firstrow(variables)
//export excel using "/Users/marcmorgan/Desktop/Survey fractile incomes.xlsx", firstrow(variables)

exit



