*----------------------------------------------------------------------------*
* Code to generate percentiles in the labour income distribuion                                   
* Brazil 2002-2015
* PNAD individual microdata (from IBGE https://www.ibge.gov.br/)
* Author: Marc Morgan
*----------------------------------------------------------------------------*

clear
set more off
cd "/Users/marcmorgan/Google Drive/PhD/Brazil/Income distribution/WID/Data/Mircodata_surveys/PNAD"

forval year=2002/2015 {

use `year'/Dados/pes`year'.dta, clear

*----------------------------------------------------------------------------*
* Variable definitions
*----------------------------------------------------------------------------*

rename v0101 year
rename v0102 control
rename v0103 series
rename v0302 sex
rename v8005 age
rename v0402 famstatus
rename v9001 working
rename v9042 formal //formal labour contract==2
rename v9906 occup
rename v9073 rural
rename v9085 contrib
rename v9088 union // rural workers==2
rename v9531 ymonet
rename v9532 yjob1
rename v9982 yjob2
rename v1022 yjob3
rename v1251 pens1
rename v1252 ypens1
rename v1254 pens2
rename v1255 ypens2
rename v1258 ypens3
rename v1261 ypens4
rename v1264 yallow
rename v1267 yrent
rename v1270 ygift
rename v1273 yfinancial
rename v9092 employ2 // self-employed==3, employer==4
rename v4706 employ1 //v4756 in 2001 survey, v4706 in rest // self-employed==9, employer==10
rename v4713 active //v4754 in 2001 survey, v4713 in rest
//rename v90531 CNPJ // Is employment registered in the CNPJ? yes==1
//rename v4711 SSC //
//rename v4719 ywork //
//rename v4720 yall1 //
//rename v4721 yhh1 //
//rename v4722 yfam1 //
//rename v4723 famtype //
rename v4724 famsize
rename v4728 location
rename v4729 weight 

* Unique id for observations
gen id=_n


tostring control series, replace
gen famid=control+series

*----------------------------------------------------------------------------*
* Define minimum wage levels
*----------------------------------------------------------------------------*

gen minwage=.
replace minwage=180 if year==2001
replace minwage=200 if year==2002
replace minwage=240 if year==2003
replace minwage=260 if year==2004
replace minwage=300 if year==2005
replace minwage=350 if year==2006
replace minwage=380 if year==2007
replace minwage=415 if year==2008
replace minwage=465 if year==2009
replace minwage=510 if year==2010
replace minwage=545 if year==2011
replace minwage=622 if year==2012
replace minwage=678 if year==2013
replace minwage=724 if year==2014
replace minwage=788 if year==2015

gen yassist=yfinancial
gen yunempl=yfinancial
replace yfinancial=. if yfinancial<=(minwage*2)
replace yunempl=. if (yunempl<=minwage | yunempl>(minwage*2))
replace yassist=. if yassist>minwage

*----------------------------------------------------------------------------*
* Define monthly exemption limit on DIRPF
*----------------------------------------------------------------------------*

gen exemptIRPF=.
replace exemptIRPF=900 if year==2001
replace exemptIRPF=1058 if year==2002 
replace exemptIRPF=1058 if year==2003
replace exemptIRPF=1058 if year==2004
replace exemptIRPF=1164 if year==2005
replace exemptIRPF=1258 if year==2006
replace exemptIRPF=1314 if year==2007
replace exemptIRPF=1373 if year==2008 
replace exemptIRPF=1435 if year==2009
replace exemptIRPF=1450 if year==2010
replace exemptIRPF=1567 if year==2011
replace exemptIRPF=1638 if year==2012
replace exemptIRPF=1711 if year==2013
replace exemptIRPF=1788 if year==2014
replace exemptIRPF=1904 if year==2015

*----------------------------------------------------------------------------*
* Filters (benchmark: narrow equal-split)
*----------------------------------------------------------------------------*

// drop if (SSC==2 | SSC==.) // only keeps contributors to social security (to compare with tax data).

// drop if (uf==11 | uf==12 | uf==13 | uf==14 | uf==15 | uf==16) & (location==4 | location==5 | location==6 | location==7 | location==8) // drops rural areas of north for 2004 survey

// drop misreported/nondeclared income
replace yjob1=. if (yjob1==999999999999 | yjob1==999999995904)
replace yjob2=. if (yjob2==999999999999 | yjob2==999999995904)
replace yjob3=. if (yjob3==999999999999 | yjob3==999999995904)
replace ypens1=. if (ypens1==999999999999 | ypens1==999999995904)
replace ypens2=. if (ypens2==999999999999 | ypens2==999999995904) 
replace ypens3=. if (ypens3==999999999999 | ypens3==999999995904) 
replace ypens4=. if (ypens4==999999999999 | ypens4==999999995904)
replace yallow=. if (yallow==999999999999  | yallow==999999995904)
replace yunempl=. if (yunempl==999999999999 | yunempl==999999995904)
replace yrent=. if (yrent==999999999999 | yrent==999999995904)
replace yfinancial=. if (yfinancial==999999999999 | yfinancial==999999995904)
replace ygift=. if (ygift==999999999999 | ygift==999999995904)
replace yassist=. if (yassist==999999999999 | yassist==999999995904)


* Missing values & zeros

replace yjob1=0 if (yjob1==. & employ1==13) // workers whose principal job is non remunerated
drop if (yjob1==. | yjob1==0) & (ymonet==1 | employ1==1 | employ1==2 | employ1==3 | employ1==4 | employ1==6 | employ1==7 | employ1==9 | employ1==10) // drop workers whose principal job is remunerated in cash but declare zero income or n.a
drop if weight==0   /* drops null weights */

*----------------------------------------------------------------------------*
* Individual adult monthly income
*----------------------------------------------------------------------------*

keep if age>=20 // | (age<20 & yind!=. & yind!=0)  /* Only keeps people above 20 years | (age<20 & yind!=. & yind!=0 & ygift!=. & ygift!=0) */

* Employee work income
gen ywork1=.
replace ywork1=yjob1 if (employ1!=9 & employ1!=10)
gen ywork2=.
replace ywork2=yjob2 if (employ2!=3 & employ2!=4)
egen ywork=rowtotal(ywork1 ywork2 yjob3)

* Employer income
// Scenario B (benchmark case): Capital withdrawals are assumed to be the excess payments over the exemption limit on DIRPF. Pro-labore payments are <= exemption limit on DIRPF
gen ycapemployer1B=.
replace ycapemployer1B=yjob1-exemptIRPF if (employ1==10 & yjob1>=exemptIRPF)

gen ylabemployer1B=yjob1-ycapemployer1B if (employ1==10 & yjob1>=exemptIRPF)
replace ylabemployer1B=yjob1 if (employ1==10 & yjob1<exemptIRPF)

gen ycapemployer2B=.
replace ycapemployer2B=yjob2-exemptIRPF if (employ2==4 & yjob2>=exemptIRPF)

gen ylabemployer2B=yjob2-ycapemployer2B if (employ2==4 & yjob2>=exemptIRPF)
replace ylabemployer2B=yjob2 if (employ2==4 & yjob2<exemptIRPF)

egen ycapemployerB=rowtotal(ycapemployer1B ycapemployer2B)
egen ylabemployerB=rowtotal(ylabemployer1B ylabemployer2B)

* Self employed income (mixed income)
gen ymixed1=.
replace ymixed1=yjob1 if employ1==9
gen ymixed2=.
replace ymixed2=yjob2 if employ2==3
egen ymixed=rowtotal(ymixed1 ymixed2)
gen ylabmix=ymixed*0.7
gen ycapmix=ymixed*0.3

* Pension income
egen ypens=rowtotal(ypens1 ypens2 ypens3 ypens4)

* Labour, capital and total individual income
egen ylabour=rowtotal(ywork ypens yallow yunempl ylabemployerB ylabmix)
egen ylabtax=rowtotal(ywork ypens yallow ylabemployerB ylabmix)
egen ycapital=rowtotal(yrent yfinancial ycapemployerB ycapmix)
egen yind=rowtotal(ylabour ycapital ymixed) // total monetary income before taxes on labour income and before social transfers for individuals 20+

*----------------------------------------------------------------------------*
* Annual income series
*----------------------------------------------------------------------------*

gen ylabtaxa=ylabtax*12 // annual adult income monthly values x 12 

*----------------------------------------------------------------------------*
* Equal split adult income (Benchmark definition) 
*----------------------------------------------------------------------------*

gen adult=0
replace adult=1 if (famstatus==1 | famstatus==2)

bysort famid (adult): egen ylabadult=sum(ylabtaxa) 
bysort famid (adult): egen adultstot=sum(adult)
gen ylab=ylabadult/adultstot if adult==1
replace ylab=ylabtaxa if adult==0 

*----------------------------------------------------------------------------*
* Totals & averages
*----------------------------------------------------------------------------*

quietly sum ylab [fw=weight]
gen tot = r(sum)
gen meant = r(mean)
gen poptot = r(sum_w)
quietly sum age [fw=weight] /*age*/
gen agem = r(mean)

replace sex=0 if sex==4
quietly sum sex [fw=weight]
gen sexm=r(mean)

*----------------------------------------------------------------------------*
* Generate fractiles
*----------------------------------------------------------------------------*

sort ylab , stable
gen cumweight=sum(weight)
format %20.0g cumweight
gen cumfrq=cumweight/poptot
format %40.0g cumfrq


*----------------------------------------------------------------------------* 
* Generate percentiles & summary stats (Mean, thresholds, shares, etc...)
*----------------------------------------------------------------------------*

* Percentiles P0-P99

gen percentile=.
forvalues i = 0(1)99 {
replace percentile=`i' if (cumfrq>=(`i')/100 & cumfrq<=(`i'+1)/100) /*    gives percentile=i if i<=cumfreq<=i+1   */
} 

forvalues i = 0(1)99 {
quietly sum ylab [fw=weight] if per==`i'
gen mean`i' = r(mean)
gen tot`i' = r(sum)
gen fractile`i' = r(min) 
//gen share`i' = tot`i'/tot 
//gen pop`i' = r(sum_w)/poptot 
}

*----------------------------------------------------------------------------* 
* Output results
*----------------------------------------------------------------------------*

keep year poptot mean*
keep if _n==1

export excel using "/Users/marcmorgan/Desktop/survey mean incomes_labour.xlsx", sheet("`year'") sheetreplace firstrow(variables) 
}

exit

