*----------------------------------------------------------------------------*
* Code to generate percentiles in the nonfiscal income distribuion for DINA estimation                                    
* Brazil 2001 and 2004 (exlcuding rural north)
* PNAD individual microdata (from IBGE https://www.ibge.gov.br/)
* Author: Marc Morgan
*----------------------------------------------------------------------------*


clear
use "/Users/marcmorgan/Google Drive/PhD/Brazil/Income distribution/WID/Data/Mircodata_surveys/PNAD/2012/Dados/pes2012.dta" // repeat for each year
set more off

*----------------------------------------------------------------------------*
* Variable definitions
*----------------------------------------------------------------------------*
rename v0101 year
rename v0102 control
rename v0103 series
rename v0302 sex
rename v8005 age
rename v0402 famstatus
rename v9001 working
rename v9042 formal //formal labour contract==2
rename v9906 occup
rename v9073 rural
rename v9059 contrib // Contributor to social insurance==1
rename v9088 union // rural workers==2
rename v9531 ymonet
rename v9532 yjob1
rename v9535 ygoods1
rename v9982 yjob2
rename v9985 ygoods2
rename v1022 yjob3
rename v1025 ygoods3
rename v1251 pens1
rename v1252 ypens1
rename v1254 pens2
rename v1255 ypens2
rename v1258 ypens3
rename v1261 ypens4
rename v9120 pensfund // contributor to private social insurance fund==2
rename v1264 yallow
rename v1267 yrent
rename v1270 ygift
rename v1273 yfinancial
rename v9092 employ2 // self-employed==3, employer==4
rename v4706 employ1 //v4756 in 2001 survey, v4706 in rest // self-employed==9, employer==10
rename v4713 active //v4754 in 2001 survey, v4713 in rest
//rename v90531 CNPJ // Is employment registered in the CNPJ? yes==1, not available before 2009
//rename v4711 SSC //
//rename v4719 ywork //
//rename v4720 yall1 //
//rename v4721 yhh1 //
//rename v4722 yfam1 //
//rename v4723 famtype //
rename v4724 famsize
rename v4728 location
rename v4729 weight

* Unique id for observations
gen id=_n


tostring control series, replace
gen famid=control+series

*----------------------------------------------------------------------------*
* Define minimum wage levels
*----------------------------------------------------------------------------*

gen minwage=.
replace minwage=180 if year==2001
replace minwage=200 if year==2002
replace minwage=240 if year==2003
replace minwage=260 if year==2004
replace minwage=300 if year==2005
replace minwage=350 if year==2006
replace minwage=380 if year==2007
replace minwage=415 if year==2008
replace minwage=465 if year==2009
replace minwage=510 if year==2010
replace minwage=545 if year==2011
replace minwage=622 if year==2012
replace minwage=678 if year==2013
replace minwage=724 if year==2014
replace minwage=788 if year==2015

gen yassist=yfinancial
gen yunempl=yfinancial
replace yfinancial=. if yfinancial<=(minwage*2)
replace yunempl=. if (yunempl<=minwage | yunempl>(minwage*2))
replace yassist=. if yassist>minwage

*----------------------------------------------------------------------------*
* Define primary component of primary income of corporations (from SNA)
*----------------------------------------------------------------------------*
gen ycorptot=.
replace ycorptot=30837391593 if year==2001
replace ycorptot=64373960752 if year==2002
replace ycorptot=91866173530 if year==2003
replace ycorptot=100158117231 if year==2004
replace ycorptot=117977246304 if year==2005
replace ycorptot=153865964372 if year==2006
replace ycorptot=182782908786 if year==2007
replace ycorptot=179047331396 if year==2008
replace ycorptot=156317085229 if year==2009
replace ycorptot=148323325103 if year==2010
replace ycorptot=203335701954 if year==2011
replace ycorptot=196404453838 if year==2012
replace ycorptot=277394097292 if year==2013
replace ycorptot=312492471792 if year==2014
replace ycorptot=346311650861 if year==2015 

*----------------------------------------------------------------------------*
* Define investment income atrributed to insurance and pension funds (from SNA)
*----------------------------------------------------------------------------*
gen yfundtot=.
replace yfundtot=12986945565 if year==2001
replace yfundtot=13431012704 if year==2002
replace yfundtot=23939361383 if year==2003
replace yfundtot=21753431806 if year==2004
replace yfundtot=21757729145 if year==2005
replace yfundtot=24969387406 if year==2006
replace yfundtot=27045090254 if year==2007
replace yfundtot=27634634675 if year==2008
replace yfundtot=37868722976 if year==2009
replace yfundtot=53539000000 if year==2010
replace yfundtot=44935000000 if year==2011
replace yfundtot=67675000000 if year==2012
replace yfundtot=40066000000 if year==2013
replace yfundtot=45993000000 if year==2014
replace yfundtot=85360000000 if year==2015 

*----------------------------------------------------------------------------*
* Define monthly exemption limit on DIRPF (from ministério da fazenda)
*----------------------------------------------------------------------------*

gen exemptIRPF=.
replace exemptIRPF=900 if year==2001
replace exemptIRPF=1058 if year==2002 
replace exemptIRPF=1058 if year==2003
replace exemptIRPF=1058 if year==2004
replace exemptIRPF=1164 if year==2005
replace exemptIRPF=1258 if year==2006
replace exemptIRPF=1314 if year==2007
replace exemptIRPF=1373 if year==2008 
replace exemptIRPF=1435 if year==2009
replace exemptIRPF=1450 if year==2010
replace exemptIRPF=1567 if year==2011
replace exemptIRPF=1638 if year==2012
replace exemptIRPF=1711 if year==2013
replace exemptIRPF=1788 if year==2014
replace exemptIRPF=1904 if year==2015

*----------------------------------------------------------------------------*
* Define monthly maximum limit on contributing salary for INSS (from ministério da previdencia social)
*----------------------------------------------------------------------------*

gen maxlimitINSS=.
replace maxlimitINSS=1430 if year==2001
replace maxlimitINSS=1562 if year==2002 
replace maxlimitINSS=1870 if year==2003
replace maxlimitINSS=2509 if year==2004
replace maxlimitINSS=2669 if year==2005
replace maxlimitINSS=2802 if year==2006
replace maxlimitINSS=2895 if year==2007
replace maxlimitINSS=3039 if year==2008 
replace maxlimitINSS=3219 if year==2009
replace maxlimitINSS=3468 if year==2010
replace maxlimitINSS=3692 if year==2011
replace maxlimitINSS=3917 if year==2012
replace maxlimitINSS=4159 if year==2013
replace maxlimitINSS=4391 if year==2014
replace maxlimitINSS=4664 if year==2015

*----------------------------------------------------------------------------*
* Filters (benchmark: narrow equal-split)
*----------------------------------------------------------------------------*

// drop if (SSC==2 | SSC==.) // only keeps contributors to social security (to compare with tax data).

drop if (uf==11 | uf==12 | uf==13 | uf==14 | uf==15 | uf==16) & (location==4 | location==5 | location==6 | location==7 | location==8) // drops rural areas of north for 2004 survey

// drop misreported/nondeclared income
replace yjob1=. if (yjob1==999999999999 | yjob1==999999995904)
replace yjob2=. if (yjob2==999999999999 | yjob2==999999995904)
replace yjob3=. if (yjob3==999999999999 | yjob3==999999995904)
replace ygoods1=. if (ygoods1==999999999999 | ygoods1==999999995904)
replace ygoods2=. if (ygoods2==999999999999 | ygoods2==999999995904)
replace ygoods3=. if (ygoods3==999999999999 | ygoods3==999999995904)
replace ypens1=. if (ypens1==999999999999 | ypens1==999999995904)
replace ypens2=. if (ypens2==999999999999 | ypens2==999999995904) 
replace ypens3=. if (ypens3==999999999999 | ypens3==999999995904) 
replace ypens4=. if (ypens4==999999999999 | ypens4==999999995904)
replace yallow=. if (yallow==999999999999  | yallow==999999995904)
replace yunempl=. if (yunempl==999999999999 | yunempl==999999995904)
replace yrent=. if (yrent==999999999999 | yrent==999999995904)
replace yfinancial=. if (yfinancial==999999999999 | yfinancial==999999995904)
replace ygift=. if (ygift==999999999999 | ygift==999999995904)
replace yassist=. if (yassist==999999999999 | yassist==999999995904)

* Missing values & zeros

replace yjob1=0 if (yjob1==. & employ1==13) // workers whose principal job is non remunerated
drop if (yjob1==. | yjob1==0) & (ymonet==1 | employ1==1 | employ1==2 | employ1==3 | employ1==4 | employ1==6 | employ1==7 | employ1==9 | employ1==10) // drop workers whose principal job is remunerated in cash but declare zero income or n.a
drop if weight==0   /* drops null weights */

*----------------------------------------------------------------------------*
* Individual adult monthly income
*----------------------------------------------------------------------------*

keep if age>=20 // | (age<20 & yind!=. & yind!=0)  /* Only keeps people above 20 years | (age<20 & yind!=. & yind!=0 & ygift!=. & ygift!=0) */

* Employee work income
gen ywork1=.
replace ywork1=yjob1 if (employ1!=9 & employ1!=10)
gen ywork2=.
replace ywork2=yjob2 if (employ2!=3 & employ2!=4)
egen ywork=rowtotal(ywork1 ywork2 yjob3)

** Employer income **
// Scenario A: Capital withdrawals are assumed to be the excess payments over the minimum wage. Pro-labore payments are = minimum wage
gen ycapemployer1A=.
replace ycapemployer1A=yjob1-minwage if (employ1==10 & yjob1>=minwage)

gen ylabemployer1A=yjob1-ycapemployer1A if (employ1==10 & yjob1>=minwage)
replace ylabemployer1A=yjob1 if (employ1==10 & yjob1<minwage)

gen ycapemployer2A=.
replace ycapemployer2A=yjob2-minwage if (employ2==4 & yjob2>=minwage)

gen ylabemployer2A=yjob2-ycapemployer2A if (employ2==4 & yjob2>=minwage)
replace ylabemployer2A=yjob2 if (employ2==4 & yjob2<minwage)

egen ycapemployerA=rowtotal(ycapemployer1A ycapemployer2A)
egen ylabemployerA=rowtotal(ylabemployer1A ylabemployer2A)

// Scenario B (benchmark case): Capital withdrawals are assumed to be the excess payments over the exemption limit on DIRPF. Pro-labore payments are <= exemption limit on DIRPF
gen ycapemployer1B=.
replace ycapemployer1B=yjob1-exemptIRPF if (employ1==10 & yjob1>=exemptIRPF)

gen ylabemployer1B=yjob1-ycapemployer1B if (employ1==10 & yjob1>=exemptIRPF)
replace ylabemployer1B=yjob1 if (employ1==10 & yjob1<exemptIRPF)

gen ycapemployer2B=.
replace ycapemployer2B=yjob2-exemptIRPF if (employ2==4 & yjob2>=exemptIRPF)

gen ylabemployer2B=yjob2-ycapemployer2B if (employ2==4 & yjob2>=exemptIRPF)
replace ylabemployer2B=yjob2 if (employ2==4 & yjob2<exemptIRPF)

egen ycapemployerB=rowtotal(ycapemployer1B ycapemployer2B)
egen ylabemployerB=rowtotal(ylabemployer1B ylabemployer2B)

// Scenario C: Capital withdrawals are assumed to be the excess payments over the maximum limit on contributing salary for INSS. Pro-labore payments are <= max limit on INSS contributing salary
gen ycapemployer1C=.
replace ycapemployer1C=yjob1-maxlimitINSS if (employ1==10 & yjob1>=maxlimitINSS)

gen ylabemployer1C=yjob1-ycapemployer1C if (employ1==10 & yjob1>=maxlimitINSS)
replace ylabemployer1C=yjob1 if (employ1==10 & yjob1<maxlimitINSS)

gen ycapemployer2C=.
replace ycapemployer2C=yjob2-maxlimitINSS if (employ2==4 & yjob2>=maxlimitINSS)

gen ylabemployer2C=yjob2-ycapemployer2C if (employ2==4 & yjob2>=maxlimitINSS)
replace ylabemployer2C=yjob2 if (employ2==4 & yjob2<maxlimitINSS)

egen ycapemployerC=rowtotal(ycapemployer1C ycapemployer2C)
egen ylabemployerC=rowtotal(ylabemployer1C ylabemployer2C)


* Self employed income (mixed income)
gen ymixed1=.
replace ymixed1=yjob1 if employ1==9
gen ymixed2=.
replace ymixed2=yjob2 if employ2==3
egen ymixed=rowtotal(ymixed1 ymixed2)

* Pension income
egen ypens=rowtotal(ypens1 ypens2 ypens3 ypens4)

* Monetary value of payment in goods
egen ygoods=rowtotal(ygoods1 ygoods2 ygoods3)

* Labour, capital and total individual income
egen ylabour=rowtotal(ywork ygoods ypens yallow yunempl ylabemployerB)
egen ycapital=rowtotal(yrent yfinancial ycapemployerB)
egen yindm=rowtotal(ylabour ycapital ymixed) // total monetary income before taxes on labour income and before social transfers for individuals 20+

*----------------------------------------------------------------------------*
* Imputing undistributed corporate profits
*----------------------------------------------------------------------------*

* Scenario 1 (benchmark): the distribution of undistributed profits assumed to follow the distribution of financial income + employer capital income 
egen yfinowner=rowtotal(yfinancial ycapemployerB)
gen yfinowner1=yfinowner*weight
egen yfinowtot=sum(yfinowner1)
gen ycorp1=((yfinowner1/yfinowtot)*ycorptot)/weight

* Scenario 2: the distribution of undistributed profits assumed to follow the distribution of capital income (financial income + property rent + employer capital income)
gen ycapital1=ycapital*weight 
egen ycaptot=sum(ycapital1)
gen ycorp2=((ycapital1/ycaptot)*ycorptot)/weight

* Scenario 3: the distribution of undistributed profits assumed to follow the distribution of financial income and property rent
egen yfinrent=rowtotal(yfinancial yrent)
gen yfinrent1=yfinrent*weight
egen yfinrenttot=sum(yfinrent1)
gen ycorp3=((yfinrent1/yfinrenttot)*ycorptot)/weight

*----------------------------------------------------------------------------*
* Imputing insurance/pension fund income 
*----------------------------------------------------------------------------*
// The distribution of insurance and pension funds are assumed to follow the distribution of income from principal job for earners who declare they contribute to a social insurance fund (public or private)

gen yjob1exp=yjob1*weight if (contrib==1 | pensfund==2)
egen yjobtot=sum(yjob1exp)
gen yfunds=((yjob1exp/yjobtot)*yfundtot)/weight 


pshare ycorp1 [fw=weight] , nquantiles(100)
exit
*----------------------------------------------------------------------------*
* New total incomes for DINA
*----------------------------------------------------------------------------*

egen ynf1=rowtotal(ycorp1 yfunds)
egen ynf2=rowtotal(ycorp2 yfunds)
egen ynf3=rowtotal(ycorp3 yfunds)

*----------------------------------------------------------------------------*
* Equal split adult income (Benchmark definition) 
*----------------------------------------------------------------------------*

gen adult=0
replace adult=1 if (famstatus==1 | famstatus==2)

bysort famid (adult): egen adultstot=sum(adult)

* Scenario 1 (benchmark):
bysort famid (adult): egen ynfadults1=sum(ynf1) 
gen yadultnf1=ynfadults1/adultstot if adult==1
replace yadultnf1=ynf1 if adult==0 
* Scenario 2:
bysort famid (adult): egen ynfadults2=sum(ynf2) 
gen yadultnf2=ynfadults2/adultstot if adult==1
replace yadultnf2=ynf2 if adult==0 
* Scenario 3:
bysort famid (adult): egen ynfadults3=sum(ynf3) 
gen yadultnf3=ynfadults3/adultstot if adult==1
replace yadultnf3=ynf3 if adult==0 

*----------------------------------------------------------------------------*
* Totals & averages
*----------------------------------------------------------------------------*

quietly sum yadultnf2 [fw=weight]
gen tot = r(sum)
gen meant = r(mean)
gen poptot = r(sum_w)

*----------------------------------------------------------------------------*
* Generate fractiles
*----------------------------------------------------------------------------*

sort yadultnf2 , stable
gen cumweight=sum(weight)
format %20.0g cumweight
gen cumfrq=cumweight/poptot
format %40.0g cumfrq

*----------------------------------------------------------------------------* 
* Generate percentiles & summary stats (Mean, thresholds, shares, etc...)
*----------------------------------------------------------------------------*

gen percentile=.
forvalues i = 0(1)99 {
replace percentile=`i' if (cumfrq>=(`i')/100 & cumfrq<=(`i'+1)/100) /*    gives percentile=i if i<cumfreq<=i+1   */
} 
/*
gen fractile1=.
forvalues i = 0(1)99 {
quietly sum yadultnf1 [fw=weight] if percentile==`i'
replace fractile1 = r(min) if percentile==`i'
}

gen mean1=.
forvalues i = 0(1)99 {
quietly sum yadultnf1 [fw=weight] if percentile==`i'
replace mean1 = r(mean) if percentile==`i'
}
*/
gen fractile2=.
forvalues i = 0(1)99 {
quietly sum yadultnf2 [fw=weight] if percentile==`i'
replace fractile2 = r(min) if percentile==`i'
}

gen mean2=.
forvalues i = 0(1)99 {
quietly sum yadultnf2 [fw=weight] if percentile==`i'
replace mean2 = r(mean) if percentile==`i'
}
/*
gen fractile3=.
forvalues i = 0(1)99 {
quietly sum yadultnf3 [fw=weight] if percentile==`i'
replace fractile3 = r(min) if percentile==`i'
}

gen mean3=.
forvalues i = 0(1)99 {
quietly sum yadultnf3 [fw=weight] if percentile==`i'
replace mean3 = r(mean) if percentile==`i'
}
*/
*----------------------------------------------------------------------------* 
* Output results
*----------------------------------------------------------------------------*

keep if percentile!=percentile[_n-1]

keep poptot meant percentile fractile* mean*

export excel using "/Users/marcmorgan/desktop/nonfiscal incomes2005.xlsx", firstrow(variables)


exit

